@@ -7,6 +7,15 @@ module Geocoder
       '192.168.0.0/16',
     ].map { |ip| IPAddr.new(ip) }.freeze
 
+    def initialize(ip)
+      ip = ip.to_string if ip.is_a?(IPAddr)
+      if ip.is_a?(Hash)
+        super(**ip)
+      else
+        super(ip)
+      end
+    end
+
     def internal?
       loopback? || private?
     end
@@ -20,7 +29,8 @@ module Geocoder
     end
 
     def valid?
-      !!((self =~ Resolv::IPv4::Regex) || (self =~ Resolv::IPv6::Regex))
+      ip = self[/(?<=\[)(.*?)(?=\])/] || self
+      !!((ip =~ Resolv::IPv4::Regex) || (ip =~ Resolv::IPv6::Regex))
     end
   end
 end
